==> mosdns-1.8.7.tar.gz: mosdns-1.8.7/README.md <==
# mosdns

功能、配置、教程等，详见: [wiki](https://github.com/IrineSistiana/mosdns/wiki)

下载预编译文件、更新日志，详见: [release](https://github.com/IrineSistiana/mosdns/releases)

docker 镜像: [docker hub](https://hub.docker.com/r/irinesistiana/mosdns)

插件和其对应的 `args` 参数说明，详见: [wiki/Plugin](https://github.com/IrineSistiana/mosdns/wiki/Plugin)

---

## Open Source Components / Libraries / Reference

依赖

* [uber-go/zap](https://github.com/uber-go/zap): [LICENSE](https://github.com/uber-go/zap/blob/master/LICENSE.txt)
* [miekg/dns](https://github.com/miekg/dns): [LICENSE](https://github.com/miekg/dns/blob/master/LICENSE)
* [go-yaml/yaml](https://github.com/go-yaml/yaml): [Apache License 2.0](https://github.com/go-yaml/yaml/blob/v2/LICENSE)
* [vishvananda/netlink](https://github.com/vishvananda/netlink): [Apache License 2.0](https://github.com/vishvananda/netlink/blob/master/LICENSE)
* [AdguardTeam/dnsproxy](https://github.com/AdguardTeam/dnsproxy): [Apache License 2.0](https://github.com/AdguardTeam/dnsproxy/blob/master/LICENSE)
* [mitchellh/mapstructure](https://github.com/mitchellh/mapstructure): [MIT](https://github.com/mitchellh/mapstructure/blob/master/LICENSE)
* [go-redis/redis](https://github.com/go-redis/redis): [BSD-2-Clause License](https://github.com/go-redis/redis/blob/master/LICENSE)
* [kardianos/service](https://github.com/kardianos/service): [zlib](https://github.com/kardianos/service/blob/master/LICENSE)

使用源码

* [v2fly/v2ray-core](https://github.com/v2fly/v2ray-core): [MIT](https://github.com/v2fly/v2ray-core/blob/master/LICENSE)
* [xtaci/smux](https://github.com/xtaci/smux): [MIT](https://github.com/xtaci/smux/blob/master/LICENSE)

参考

* [coredns/coredns](https://github.com/coredns/coredns)

==> mosdns-3.0.0.tar.gz: mosdns-3.0.0/README.md <==
# mosdns

功能概述、配置方式、教程等，详见: [wiki](https://github.com/IrineSistiana/mosdns/wiki)

下载预编译文件、更新日志，详见: [release](https://github.com/IrineSistiana/mosdns/releases)

docker 镜像: [docker hub](https://hub.docker.com/r/irinesistiana/mosdns)

快速查找插件和其对应的 `args` 参数说明: [wiki/Plugin](https://github.com/IrineSistiana/mosdns/wiki/Plugin)

---

## Open Source Components / Libraries / Reference

依赖

* [uber-go/zap](https://github.com/uber-go/zap): [LICENSE](https://github.com/uber-go/zap/blob/master/LICENSE.txt)
* [miekg/dns](https://github.com/miekg/dns): [LICENSE](https://github.com/miekg/dns/blob/master/LICENSE)
* [go-yaml/yaml](https://github.com/go-yaml/yaml): [Apache License 2.0](https://github.com/go-yaml/yaml/blob/v2/LICENSE)
* [vishvananda/netlink](https://github.com/vishvananda/netlink): [Apache License 2.0](https://github.com/vishvananda/netlink/blob/master/LICENSE)
* [AdguardTeam/dnsproxy](https://github.com/AdguardTeam/dnsproxy): [Apache License 2.0](https://github.com/AdguardTeam/dnsproxy/blob/master/LICENSE)
* [mitchellh/mapstructure](https://github.com/mitchellh/mapstructure): [MIT](https://github.com/mitchellh/mapstructure/blob/master/LICENSE)
* [go-redis/redis](https://github.com/go-redis/redis): [BSD-2-Clause License](https://github.com/go-redis/redis/blob/master/LICENSE)
* [kardianos/service](https://github.com/kardianos/service): [zlib](https://github.com/kardianos/service/blob/master/LICENSE)
* [google/nftables](https://github.com/google/nftables): [Apache-2.0 License](https://github.com/google/nftables/blob/master/LICENSE)
* [protocolbuffers/protobuf-go](https://github.com/protocolbuffers/protobuf-go): [BSD-3-Clause](https://github.com/protocolbuffers/protobuf-go/blob/master/LICENSE)

使用源码

* [v2fly/v2ray-core](https://github.com/v2fly/v2ray-core): [MIT](https://github.com/v2fly/v2ray-core/blob/master/LICENSE)
* [xtaci/smux](https://github.com/xtaci/smux): [MIT](https://github.com/xtaci/smux/blob/master/LICENSE)

参考

* [coredns/coredns](https://github.com/coredns/coredns)
